api.authentication.v1.test_helpers.methods package — Argus-Toolbelt 1.0 documentation

# api.authentication.v1.test_helpers.methods package

## Submodules

## api.authentication.v1.test_helpers.methods.get_methods module

`api.authentication.v1.test_helpers.methods.get_methods.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/methods, respond with HTTP 403

`api.authentication.v1.test_helpers.methods.get_methods.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/methods, respond with HTTP 404

`api.authentication.v1.test_helpers.methods.get_methods.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/methods, respond with HTTP 200

`api.authentication.v1.test_helpers.methods.get_methods.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/authentication/v1/methods, respond with HTTP 401

## Module contents